@@ -7,18 +7,18 @@ use Safe;
 
 ######################################################################
 
+use vars qw( %Defaults %Filters );
+
 # Output filtering
-use vars qw( %Filters );
+$Defaults{default_filters} = '';
+$Defaults{filters} = \%Filters;
+
 $Filters{p} = \&Text::MicroMason::Base::_printable;
-
-$Filters{h} = eval { 
-      require HTML::Entities; sub { HTML::Entities::encode( $_[0], q[<>&'"] ) } 
-    } || eval { require CGI; \&CGI::escapeHTML };
-
-$Filters{u} = eval { require URI::Escape; \&URI::Escape::uri_escape };
+$Filters{h} = \&HTML::Entities::encode if eval { require HTML::Entities};
+$Filters{u} = \&URI::Escape::uri_escape if eval { require URI::Escape };
 
 sub defaults {
-  (shift)->NEXT('defaults'), filters => \%Filters, default_filters => ''
+  (shift)->NEXT('defaults'), %Text::MicroMason::Filters::Defaults
 }
 
 ######################################################################
@@ -31,7 +31,7 @@ sub assemble {
   foreach my $position ( 0 .. int( $#tokens / 2 ) ) {
     if ( $tokens[$position * 2] eq 'expr' ) {
       my $token = $tokens[$position * 2 + 1];
-      my $filt_flags = ($token =~ s/[^\|]\|\s*(\w+(?:[\s\,]+\w+)*)\s*\z//) ? $1 : '';
+      my $filt_flags = ($token =~ s/\|\s*(\w+(?:[\s\,]+\w+)*)\s*\z//) ? $1 : '';
       my @filters = $self->parse_filters($self->{default_filters}, $filt_flags);
       if ( @filters ) {
 	$token = '$m->filter( ' . join(', ', map "'$_'", @filters ) . ', ' . 
@@ -117,11 +117,6 @@ Instead of using this class directly, pass its name to be mixed in:
     use Text::MicroMason;
     my $mason = Text::MicroMason->new( -Filters );
 
-Use the standard compile and execute methods to parse and evalute templates:
-
-  print $mason->compile( text=>$template )->( @%args );
-  print $mason->execute( text=>$template, @args );
-
 Enables filtering of template expressions using HTML::Mason's conventions:
 
     <%args> $name </%args>
@@ -222,7 +217,7 @@ Applies one or more filters to the provided content string.
 
 For an overview of this templating framework, see L<Text::MicroMason>.
 
-This is a mixin class intended for use with L<Text::MicroMason::HTMLMason>.
+This is a mixin class intended for use with L<Text::MicroMason::Mason>.
 
 For distribution, installation, support, copyright and license 
 information, see L<Text::MicroMason::Docs::ReadMe>.
